@@ -15,7 +15,7 @@ package UR::DataSource::File;
 use UR;
 use strict;
 use warnings;
-our $VERSION = "0.26"; # UR $VERSION;
+our $VERSION = "0.27"; # UR $VERSION;
 
 use Fcntl qw(:DEFAULT :flock);
 use Errno qw(EINTR EAGAIN);
@@ -909,7 +909,7 @@ sub create_from_inline_class_data {
     $ds_data->{'server'} ||= $ds_data->{'path'} || $ds_data->{'file'};
 
     my %ds_creation_params;
-    foreach my $param ( qw( delimieter record_separator column_order skip_first_line server file_list sort_order constant_values ) ) {
+    foreach my $param ( qw( delimiter record_separator column_order skip_first_line server file_list sort_order constant_values ) ) {
         if (exists $ds_data->{$param}) {
             if ($creation_param_is_list{$param} and ref($ds_data->{$param}) ne 'ARRAY') {
                 $ds_creation_params{$param} = \( $ds_data->{$param} );
