@@ -1,8 +1,6 @@
 package UR::Object::Command::List::Style;
 
-our $VERSION = "0.44_01"; # UR $VERSION;
-
-sub new {
+sub new{
     my ($class, %args) = @_;
     foreach (qw/iterator show noheaders output/){
         die "no value for $_!" unless defined $args{$_};
@@ -23,58 +21,35 @@ sub _get_next_object_from_iterator {
     }
     return $obj;
 }
+        
 
 sub _object_properties_to_string {
     my ($self, $o, $char) = @_;
     my @v;
     return join(
-        $char,
-        map { defined $_ ? $_ : '<NULL>' }
-        map {
-            $self->_object_property_to_string($o,$_)
+        $char, 
+        map { defined $_ ? $_ : '<NULL>' } 
+        map { 
+            if (substr($_,0,1) eq '(') {
+                @v = eval $_;
+                if ($@) {
+                    @v = ('<ERROR>'); # ($@ =~ /^(.*)$/);
+                }
+            }
+            else {
+                @v = map { defined $_ ? $_ : '<NULL>' } $o->$_;
+            }
+            if (@v > 1) {
+                no warnings;
+                join(',',@v)
+            }
+            else {
+                $v[0]
+            }
         } @{$self->{show}}
     );
 }
 
-sub _object_property_to_string {
-    my ($self, $o, $property) = @_;
-
-    my @v;
-    if (substr($property,0,1) eq '(') {
-        @v = eval $property;
-        if ($@) {
-            @v = ('<ERROR>'); # ($@ =~ /^(.*)$/);
-        }
-    }
-    else {
-        @v = ();
-        foreach my $i ($o->__get_attr__($property)) {
-            if (! defined $i) {
-                push @v, "<NULL>";
-            } 
-            elsif (Scalar::Util::blessed($i) and $i->isa('UR::Value') and $i->can('create_view')) {
-                # Here we allow any UR::Values that have their own views to present themselves.
-                my $v = $i->create_view( perspective => 'default', toolkit => 'text' );
-                push @v, $v->content();
-            }
-            elsif (Scalar::Util::blessed($i) and $i->can('__display_name__')) {
-                push @v, $i->__display_name__;
-            } 
-            else {
-                push @v, $i;
-            }
-        }
-    }
-
-    if (@v > 1) {
-        no warnings;
-        return join(' ',@v);
-    }
-    else {
-        return $v[0];
-    }
-}
-
 sub format_and_print{
     my $self = shift;
 
@@ -144,23 +119,6 @@ sub _get_object_string {
     return $self->_object_properties_to_string($object, $self->{'csv_delimiter'});
 }
 
-package UR::Object::Command::List::Tsv;
-use base 'UR::Object::Command::List::Csv';
-
-sub _get_header_string{
-    my $self = shift;
-
-    my $delimiter = "\t";
-    return join($delimiter, map { lc } @{$self->{show}});
-}
-
-sub _get_object_string {
-    my ($self, $object) = @_;
-
-    return $self->_object_properties_to_string($object, "\t");
-}
-
-
 package UR::Object::Command::List::Pretty;
 use base 'UR::Object::Command::List::Style';
 
@@ -174,7 +132,7 @@ sub _get_object_string{
     my $out;
     for my $property ( @{$self->{show}} )
     {
-        my $value = join(', ', $self->_object_property_to_string($object,$property));
+        my $value = join(', ', $object->$property);
         $out .= sprintf(
             "%s: %s\n",
             Term::ANSIColor::colored($property, 'red'),
@@ -199,7 +157,7 @@ sub format_and_print{
 
     my $doc = XML::LibXML->createDocument();
     my $results_node = $doc->createElement("results");
-    $results_node->addChild( $doc->createAttribute("generated-at",$UR::Context::current->now()) );
+    $results_node->addChild( $doc->createAttribute("generated-at",UR::Time->now()) );
 
     $doc->setDocumentElement($results_node);
 
@@ -215,7 +173,7 @@ sub format_and_print{
 
              my $property_node = $object_node->addChild ($doc->createElement($property));
 
-             my @items = $self->_object_property_to_string($object, $property);
+             my @items = $object->$property;
 
              my $reftype = ref $items[0];
 
